@@ -19,11 +19,11 @@ sub process{
     my $leak_id;
 
     if ( ($leak_id = $uri->query_param('i')) && ($leak_id =~ m/$validate_reg/) ){
-        return '<object width="' . $embeder->width . '" height="' . $embeder->height . '">'
+        return '<object class="' . $embeder->class . '">'
             .'<param name="movie" value="http://www.liveleak.com/e/' . $leak_id . '" />'
             .'<param name="wmode" value="transparent" />'
             .'<embed src="http://www.liveleak.com/e/' . $leak_id . '" type="application/x-shockwave-flash"'
-            .' wmode="transparent" width="' . $embeder->width . '" height="' . $embeder->height . '">'
+            .' wmode="transparent" class="' . $embeder->class . '">'
             .'</embed></object>';
     }
 
