@@ -19,11 +19,11 @@ sub process{
     my $megavideo_id;
 
     if ( ($megavideo_id = $uri->query_param('v')) && ($megavideo_id =~ m/$validate_reg/) ){
-        return '<object width="' . $embeder->width . '" height="' . $embeder->height . '">'
+        return '<object class="' . $embeder->class . '">'
             .'<param name="movie" value="http://www.megavideo.com/v/' . $megavideo_id . '" />'
             .'<param name="allowFullScreen" value="true" />'
             .'<embed src="http://www.megavideo.com/v/' . $megavideo_id . '" type="application/x-shockwave-flash" '
-            .'allowfullscreen="true" width="' . $embeder->width . '" height="' . $embeder->height . '"></embed></object>';
+            .'allowfullscreen="true" class="' . $embeder->class . '"></embed></object>';
     }
 
     return undef;
